Struct cairo::ImageSurface
source · [−]pub struct ImageSurface(_);Implementations
sourceimpl ImageSurface
impl ImageSurface
pub unsafe fn from_raw_full(
ptr: *mut cairo_surface_t
) -> Result<ImageSurface, Status>
pub fn create(
format: Format,
width: i32,
height: i32
) -> Result<ImageSurface, Status>
pub fn create_for_data<D: AsMut<[u8]> + 'static>(
data: D,
format: Format,
width: i32,
height: i32,
stride: i32
) -> Result<ImageSurface, Status>
pub fn get_data(&mut self) -> Result<ImageSurfaceData<'_>, BorrowError>
pub fn get_format(&self) -> Format
pub fn get_height(&self) -> i32
pub fn get_stride(&self) -> i32
pub fn get_width(&self) -> i32
Methods from Deref<Target = Surface>
pub fn to_raw_none(&self) -> *mut cairo_surface_t
pub fn create_similar(&self, content: Content, width: i32, height: i32) -> Surface
pub fn get_mime_data(&self, mime_type: &str) -> Option<Vec<u8>>
pub unsafe fn get_mime_data_raw(&self, mime_type: &str) -> Option<&[u8]>
pub fn set_mime_data<T: AsRef<[u8]> + 'static>(
&self,
mime_type: &str,
slice: T
) -> Result<(), Status>
pub fn supports_mime_type(&self, mime_type: &str) -> bool
pub fn set_device_offset(&self, x_offset: f64, y_offset: f64)
pub fn get_device_offset(&self) -> (f64, f64)
pub fn set_fallback_resolution(
&self,
x_pixels_per_inch: f64,
y_pixels_per_inch: f64
)
pub fn get_fallback_resolution(&self) -> (f64, f64)
pub fn create_similar_image(
&self,
format: Format,
width: i32,
height: i32
) -> Option<Surface>
pub fn map_to_image(
&self,
extents: Option<RectangleInt>
) -> Result<MappedImageSurface, Status>
sourcepub fn set_user_data<T: 'static>(
&self,
key: &'static UserDataKey<T>,
value: Rc<T>
)
pub fn set_user_data<T: 'static>(
&self,
key: &'static UserDataKey<T>,
value: Rc<T>
)
Attach user data to self for the given key.
sourcepub fn get_user_data<T: 'static>(
&self,
key: &'static UserDataKey<T>
) -> Option<Rc<T>>
pub fn get_user_data<T: 'static>(
&self,
key: &'static UserDataKey<T>
) -> Option<Rc<T>>
Return the user data previously attached to self with the given key, if any.
sourcepub fn get_user_data_ptr<T: 'static>(
&self,
key: &'static UserDataKey<T>
) -> Option<NonNull<T>>
pub fn get_user_data_ptr<T: 'static>(
&self,
key: &'static UserDataKey<T>
) -> Option<NonNull<T>>
Return the user data previously attached to self with the given key, if any,
without incrementing the reference count.
The pointer is valid when it is returned from this method,
until the cairo object that self represents is destroyed
or remove_user_data or set_user_data is called with the same key.
sourcepub fn remove_user_data<T: 'static>(&self, key: &'static UserDataKey<T>)
pub fn remove_user_data<T: 'static>(&self, key: &'static UserDataKey<T>)
Unattach from self the user data associated with key, if any.
If there is no other Rc strong reference, the data is destroyed.