pub struct MappedImageSurface { /* private fields */ }

Methods from Deref<Target = ImageSurface>

Methods from Deref<Target = Surface>

Attach user data to self for the given key.

Return the user data previously attached to self with the given key, if any.

Return the user data previously attached to self with the given key, if any, without incrementing the reference count.

The pointer is valid when it is returned from this method, until the cairo object that self represents is destroyed or remove_user_data or set_user_data is called with the same key.

Unattach from self the user data associated with key, if any. If there is no other Rc strong reference, the data is destroyed.