Struct cairo::PdfOutline
source · [−]pub struct PdfOutline { /* private fields */ }Implementations
sourceimpl PdfOutline
impl PdfOutline
pub const OPEN: PdfOutline = _
pub const BOLD: PdfOutline = _
pub const ITALIC: PdfOutline = _
sourcepub const fn empty() -> PdfOutline
pub const fn empty() -> PdfOutline
Returns an empty set of flags
sourcepub const fn all() -> PdfOutline
pub const fn all() -> PdfOutline
Returns the set containing all flags.
sourcepub fn from_bits(bits: i32) -> Option<PdfOutline>
pub fn from_bits(bits: i32) -> Option<PdfOutline>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: i32) -> PdfOutline
pub const fn from_bits_truncate(bits: i32) -> PdfOutline
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> PdfOutline
pub const unsafe fn from_bits_unchecked(bits: i32) -> PdfOutline
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: PdfOutline) -> bool
pub const fn intersects(&self, other: PdfOutline) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: PdfOutline) -> bool
pub const fn contains(&self, other: PdfOutline) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: PdfOutline)
pub fn insert(&mut self, other: PdfOutline)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: PdfOutline)
pub fn remove(&mut self, other: PdfOutline)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: PdfOutline)
pub fn toggle(&mut self, other: PdfOutline)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: PdfOutline, value: bool)
pub fn set(&mut self, other: PdfOutline, value: bool)
Inserts or removes the specified flags depending on the passed value.