[−][src]Struct cairo::Surface
Methods
impl Surface[src]
pub unsafe fn from_raw_none(ptr: *mut cairo_surface_t) -> Surface[src]
pub unsafe fn from_raw_borrow(ptr: *mut cairo_surface_t) -> Surface[src]
pub unsafe fn from_raw_full(ptr: *mut cairo_surface_t) -> Surface[src]
pub fn to_raw_none(&self) -> *mut cairo_surface_t[src]
pub fn create_similar(
&self,
content: Content,
width: i32,
height: i32
) -> Surface[src]
&self,
content: Content,
width: i32,
height: i32
) -> Surface
pub fn get_mime_data(&self, mime_type: &str) -> Option<Vec<u8>>[src]
pub unsafe fn get_mime_data_raw(&self, mime_type: &str) -> Option<&[u8]>[src]
pub fn set_mime_data<T: AsRef<[u8]> + 'static>(
&self,
mime_type: &str,
slice: T
) -> Result<(), Status>[src]
&self,
mime_type: &str,
slice: T
) -> Result<(), Status>
pub fn supports_mime_type(&self, mime_type: &str) -> bool[src]
pub fn set_device_offset(&self, x_offset: f64, y_offset: f64)[src]
pub fn get_device_offset(&self) -> (f64, f64)[src]
pub fn set_fallback_resolution(
&self,
x_pixels_per_inch: f64,
y_pixels_per_inch: f64
)[src]
&self,
x_pixels_per_inch: f64,
y_pixels_per_inch: f64
)
pub fn get_fallback_resolution(&self) -> (f64, f64)[src]
pub fn create_similar_image(
&self,
format: Format,
width: i32,
height: i32
) -> Option<Surface>[src]
&self,
format: Format,
width: i32,
height: i32
) -> Option<Surface>
pub fn map_to_image(
&self,
extents: Option<RectangleInt>
) -> Result<MappedImageSurface, Status>[src]
&self,
extents: Option<RectangleInt>
) -> Result<MappedImageSurface, Status>
pub fn set_user_data<T: 'static>(
&self,
key: &'static UserDataKey<T>,
value: Rc<T>
)[src]
&self,
key: &'static UserDataKey<T>,
value: Rc<T>
)
Attach user data to self for the given key.
pub fn get_user_data<T: 'static>(
&self,
key: &'static UserDataKey<T>
) -> Option<Rc<T>>[src]
&self,
key: &'static UserDataKey<T>
) -> Option<Rc<T>>
Return the user data previously attached to self with the given key, if any.
pub fn get_user_data_ptr<T: 'static>(
&self,
key: &'static UserDataKey<T>
) -> Option<NonNull<T>>[src]
&self,
key: &'static UserDataKey<T>
) -> Option<NonNull<T>>
Return the user data previously attached to self with the given key, if any,
without incrementing the reference count.
The pointer is valid when it is returned from this method,
until the cairo object that self represents is destroyed
or remove_user_data or set_user_data is called with the same key.
pub fn remove_user_data<T: 'static>(&self, key: &'static UserDataKey<T>)[src]
Unattach from self the user data associated with key, if any.
If there is no other Rc strong reference, the data is destroyed.
impl Surface[src]
pub fn flush(&self)[src]
pub fn finish(&self)[src]
pub fn get_type(&self) -> SurfaceType[src]
pub fn status(&self) -> Status[src]